Authors
=======

``joserfc`` is written and maintained by `Hsiaoming Yang <https://lepture.com>`_.


Contributors
------------

Here is the list of the main contributors:

- `Viicos <https://github.com/Viicos>`_
- `Alon Bar-Lev <https://github.com/alonbl>`_

And more on https://github.com/authlib/joserfc/graphs/contributors
